@@ -93,7 +93,7 @@ def check_unit_tests(directory: str, verbose: bool, tests: bool, variables_passe
 
             if failures:
                 print_error(output)
-                return int(re.findall(r'failures=(\d+)', output)[0])
+                return int(failures)
             print_ok('', verbose)
             return 0
     return 0
@@ -106,7 +106,7 @@ def check_garpix_page_tests(verbose: bool, garpix_page: bool, variables_passed:
 
         if failures:
             print_error(output)
-            return int(re.findall(r'failures=(\d+)', output)[0])
+            return int(failures)
         print_ok('', verbose)
     return 0
 
